==> xJdfLib-0.3-sources.jar: org/cip4/lib/xjdf/schema/ProofingIntent.java <==

package org.cip4.lib.xjdf.schema;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ProofingIntent complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ProofingIntent">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.CIP4.org/JDFSchema_2_0}IntentType">
 *       &lt;sequence>
 *         &lt;choice>
 *           &lt;element ref="{http://www.CIP4.org/JDFSchema_2_0}ProofItem" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;/choice>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ProofingIntent", propOrder = {
    "proofItems"
})
public class ProofingIntent
    extends IntentType
    implements Serializable
{

    @XmlElement(name = "ProofItem")
    protected List<ProofItem> proofItems;

    /**
     * Gets the value of the proofItems property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the proofItems property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getProofItems().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ProofItem }
     * 
     * 
     */
    public List<ProofItem> getProofItems() {
        if (proofItems == null) {
            proofItems = new ArrayList<ProofItem>();
        }
        return this.proofItems;
    }

}

==> xJdfLib-0.4-sources.jar: org/cip4/lib/xjdf/schema/ProofingIntent.java <==

package org.cip4.lib.xjdf.schema;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ProofingIntent complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ProofingIntent">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.CIP4.org/JDFSchema_2_0}IntentType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.CIP4.org/JDFSchema_2_0}ProofItem" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ProofingIntent", propOrder = {
    "proofItem"
})
public class ProofingIntent
    extends IntentType
    implements Serializable
{

    @XmlElement(name = "ProofItem")
    protected List<ProofItem> proofItem;

    /**
     * Gets the value of the proofItem property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the proofItem property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getProofItem().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ProofItem }
     * 
     * 
     */
    public List<ProofItem> getProofItem() {
        if (proofItem == null) {
            proofItem = new ArrayList<ProofItem>();
        }
        return this.proofItem;
    }

}
